@@ -1,4 +1,4 @@
-globalVariables(c("Time", "Count", "Sensor", "Date", "Date_Time", "walk"))
+globalVariables(c("Time", "Count", "Sensor", "Date", "Date_Time", "walk", "sensor"))
 
 #' API using compedapi to Melbourne pedestrian data
 #'
@@ -111,7 +111,7 @@ interp_time <- function(x) {
 
 read_url <- function(url) {
   utils::read.csv(
-    url, skip = 8, nrows = 43,
+    url, skip = 8, nrows = 63,
     colClasses = c("character", rep("integer", 24)),
     na.strings = "N/A", stringsAsFactors = FALSE, check.names = FALSE
   )
